@@ -403,6 +403,10 @@ SYSTEM = click.option(
     '--system', required=False, default=None, type=click.BOOL, metavar='[True|False]',
     help="Filter on logs generated by the system (true) or generated by user code (false)"
 )
+LEVEL = click.option(
+    '--level', required=False, default=None, type=click.STRING, metavar='[info|error]',
+    help="Filter on logs according to the level of the log"
+)
 START_DATE = click.option(
     '--start_date', required=False, default=None, metavar='<datetime in iso-format>',
     help="Start date of the interval for which the logs are retrieved. Formatted like '2020-01-01T00:00:00.000000Z'. "
